/******************************************************************************
Author: Samuel Jero

Date: 12/2010

Description:  LTP Header manipulation functions

******************************************************************************/
#include "ltp.h"


/*
 * SDNV has a zero in high-order bit position of last byte. The high-order
 * bit of all preceding bytes is set to one. This returns the numeric value
 * in an integer and sets the value of the second argument to the number of
 * bytes used to code the SDNV. A -1 is returned if the evaluation fails
 * (value exceeds maximum for signed integer). 0 is an acceptable value.
 */

#define SDNV_MASK	0x7f

/*2rd arg is number of bytes in field (returned)*/
int evaluate_sdnv(const u_char* loc, int *bytecount)
{
    int value = 0;
    u_char curbyte;

    *bytecount = 0;

    /*
     * Get 1st byte and continue to get them while high-order bit is 1
     */

    while((curbyte = *(loc++)) & ~SDNV_MASK) {
	if(*bytecount >= (int) sizeof(int)) {
	    *bytecount = 0;
	    return -1;
	}
	value = value << 7;
	value |= (curbyte & SDNV_MASK);
	++*bytecount;
    }

    /*
     * Add in the byte whose high-order bit is 0 (last one)
     */

    value = value << 7;
    value |= (curbyte & SDNV_MASK);
    ++*bytecount;
    return value;
}

/* Special Function to evaluate 64 bit SDNVs */
long long evaluate_sdnv_64(const u_char* loc, int *bytecount)
{
    long long value = 0;
    u_char curbyte;

    *bytecount = 0;

    /*
     * Get 1st byte and continue to get them while high-order bit is 1
     */

    while((curbyte = *(loc++)) & ~SDNV_MASK) {
	if(*bytecount >= (int) sizeof(long long)) {
	    *bytecount = 0;
	    return -1;
	}
	value = value<< 7;
	value |= (curbyte & SDNV_MASK);
	++*bytecount;
    }

    /*
     * Add in the byte whose high-order bit is 0 (last one)
     */

    value = value << 7;
    value |= (curbyte & SDNV_MASK);
    ++*bytecount;
    return value;
}
