/******************************************************************************

File: ltp.h

Author: Samuel Jero

Date: 12/2010

Description:  LTP Header information

******************************************************************************/

#ifndef LTP_H_
#define LTP_H_
#include <stdlib.h>

/* structure to hold all the data from an LTP header.
 *  Note that this isn't the RAW header like in IP,TCP;
 *  it is a structure to hold all the information. The
 *  RAW header is mostly SDNV values
 */
struct ltp_hdr_d{
	u_char 	vers_ctl;		/* Version and Control Field*/
	int 	sender_id;		/* Session sender id*/
	int 	session_num;	/* session number */
	u_char 	extensions;		/* number of extensions field (split header/trailer)*/
	int 	cls_id;			/* Data segment Client Service ID */
	int 	offset;			/* Data segment data offset*/
	int 	length;			/* Data segment data length*/
	int 	checkpoint;		/* Checkpoint number */
	int 	report;			/* Report Number */
	int 	ubound;			/* Report Upper Bound*/
	int 	lbound;			/* Report Lower Bound*/
	int 	rclaims;		/* Number of Reception Claims for Report */
	int 	reason;			/* Cancellation Reason code */
};

/* SDNV manipulation functions*/
int evaluate_sdnv(const u_char* loc, int *bytecount);
long long evaluate_sdnv_64(const u_char* loc, int *bytecount);

#endif
