/******************************************************************************

file: ltp2tcp.h

Author: Samuel Jero

Date: 12/2010

Description:  Header file for LTP 2 TCP Conversion


Special Types Used:
	1)u_char
	2)u_int32_t
******************************************************************************/
#ifndef _LTP2TCP_H_
#define _LTP2TCP_H_

#include <stdlib.h>
#include <stdarg.h>
#include <string.h>
#include <arpa/inet.h>
#include <netinet/tcp.h>
#include <pcap.h>
#include "ltp.h"
#include "encap.h"




extern int debug;			/*set to 1 to turn on debugging information, see ltp2tcp.c*/
extern int MAX_SESSION;		/* max session size, see ltp2tcp.c*/




/*session table*/
struct session{
	int 		max;		/*max used session*/
	struct tbl 	*table;		/*session table */
	int 		size;		/*session table size */
};

/*session table structure*/
struct tbl{
	int 		num;		/*LTP session num */
	u_int32_t	start;		/*start sequence number*/
	int			acked;		/* length of session that has been acked */
	int			length;		/* length of session */
	int			seq_id;		/*sequential Session id*/
	struct cl*	a_lst;		/*list of claims*/
};

/*claim structure*/
struct cl{
	struct cl*	next;		/*pointer to next claim*/
	int 		offset;		/*offset for this data piece*/
	int 		length;		/*length of this data peice*/
};

/*converter state*/
struct conversion_state{
	int 				seq_num;	/* Largest TCP sequence Number used*/
	int 				ack_num;	/* Largest TCP acknowledgment Number used*/
	int 				win;		/* Largest TCP window used*/
	int 				started;	/* 1 if we have found any LTP so far, 0 otherwise*/
	int					sender_id;	/* LTP sender ID for this connection*/
	int					seq_ses_id; /* Number of LTP sessions in this connection so far*/
	struct session 		ses;		/* Session Table Structure*/
	void*				en_priv;	/* Pointer for Encapsulation data*/
	struct encap_ops*	en_ops;		/* Pointer to encapsulation operations*/
	pcap_t*				in;			/*libpcap input file discriptor*/
	pcap_dumper_t*		out;		/*libpcap output file discriptor*/
	int					ses_min;	/*session filtering: low*/
	int					ses_max;	/*session filtering: high*/
};
struct conversion_state state;

#define MAX_PACKET 	1600		/*Maximum size of TCP packet*/
#define	WIN_FACTOR	10000		/*Size of TCP window*/
#define	TBL_SZ		10000		/*Size of Session Table*/



/*debug printf
 * Levels:
 * 	0) Always print even if debug isn't specified
 *  1) Errors and warnings... Don't overload the screen with too much output
 *  2) Notes and per-packet processing info... as verbose as needed
 */
void dbgprintf(int level, const char *fmt, ...);


#endif
